=======
Credits
=======

Development Lead
----------------

* `Nasim Rahaman <https://github.com/nasimrahaman>`_  @ `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ , `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,


Contributors
------------

In no particular order,
  *   `Steffen Wolf <https://github.com/Steffen-Wolf>`_  @ 
      `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ ,
      `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,
  *   `Maurice Weiler <https://github.com/mauriceweiler>`_  @ 
      `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ ,
      `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,   
  *   `Constantin Pape <https://github.com/constantinpape>`_  @ 
      `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ ,
      `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,

  *   `Sven Peter <https://github.com/svenpeter42>`_  @ 
      `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ ,
      `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,
  *   `Manuel Haussmann <https://github.com/manuelhaussmann>`_  @ 
      `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ ,
      `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,
  *   `Thorsten Beier <https://github.com/DerThorsten>`_  @ 
      `Image Analysis and Learning Lab <https://hci.iwr.uni-heidelberg.de/mip>`_ ,
      `Heidelberg Collaboratory for Image Processing <https://hci.iwr.uni-heidelberg.de/>`_ ,
